aboutsummaryrefslogtreecommitdiffstats
path: root/phpBB/phpbb/event/php_exporter.php
diff options
context:
space:
mode:
Diffstat (limited to 'phpBB/phpbb/event/php_exporter.php')
-rw-r--r--phpBB/phpbb/event/php_exporter.php8
1 files changed, 4 insertions, 4 deletions
diff --git a/phpBB/phpbb/event/php_exporter.php b/phpBB/phpbb/event/php_exporter.php
index 8923d35f6d..ae3553c558 100644
--- a/phpBB/phpbb/event/php_exporter.php
+++ b/phpBB/phpbb/event/php_exporter.php
@@ -508,7 +508,7 @@ class php_exporter
}
/**
* Find the "@change" Information lines
*
* @param string $tag_name Should be 'change', not 'changed'
* @return array Absolute line numbers
@@ -648,7 +648,7 @@ class php_exporter
}
/**
- * Validate "@change" Information
+ * Validate "@changed" Information
*
* @param string $line
* @return string
@@ -658,10 +658,10 @@ class php_exporter
{
$match = array();
$line = str_replace("\t", ' ', ltrim($line, "\t "));
- preg_match('#^\* @change (\d+\.\d+\.\d+(?:-(?:a|b|RC|pl)\d+)?)( (?:.*))?$#', $line, $match);
+ preg_match('#^\* @changed (\d+\.\d+\.\d+(?:-(?:a|b|RC|pl)\d+)?)( (?:.*))?$#', $line, $match);
if (!isset($match[2]))
{
- throw new \LogicException("Invalid '@change' information for event "
+ throw new \LogicException("Invalid '@changed' information for event "
. "'{$this->current_event}' in file '{$this->current_file}:{$this->current_event_line}'");
}
@@ -508,7 +508,7 @@ class php_exporter
}
/**
- * Find the "@change" Information lines
+ * Find the "@changed" Information lines
*
* @param string $tag_name Should be 'change', not 'changed'